@@ -20,10 +20,14 @@ from zope.i18n import translate
 from zope.i18nmessageid import MessageFactory
 from zope.schema.interfaces import IVocabularyFactory
 
+import logging
 import json
 import zope.deferredimport
 
 
+logger = logging.getLogger("plone.app.widgets.utils")
+
+
 _ = MessageFactory('plone')
 
 
@@ -41,25 +45,9 @@ def get_date_options(request):
     calendar = request.locale.dates.calendars['gregorian']
     today = datetime.today()
     return {
-        'time': False,
-        'date': {
-            'firstDay': calendar.week.get('firstDay') == 1 and 1 or 0,
-            'weekdaysFull': [
-                calendar.days.get(t, (None, None))[0]
-                for t in (7, 1, 2, 3, 4, 5, 6)],
-            'weekdaysShort': [
-                calendar.days.get(t, (None, None))[1]
-                for t in (7, 1, 2, 3, 4, 5, 6)],
-            'monthsFull': calendar.getMonthNames(),
-            'monthsShort': calendar.getMonthAbbreviations(),
-            'selectYears': 200,
-            'min': [today.year - 100, 1, 1],
-            'max': [today.year + 20, 1, 1],
-            'format': translate(
-                _('pickadate_date_format', default='mmmm d, yyyy'),
-                context=request),
-            'placeholder': translate(_('Enter date...'), context=request),
-        },
+        'behavior': 'native',
+        'week-numbers': 'show',
+        'first-day': calendar.week.get('firstDay') == 1 and 1 or 0,
         'today': translate(_(u"Today"), context=request),
         'clear': translate(_(u"Clear"), context=request),
     }
@@ -67,12 +55,6 @@ def get_date_options(request):
 
 def get_datetime_options(request):
     options = get_date_options(request)
-    options['time'] = {
-        'format': translate(
-            _('pickadate_time_format', default='h:i a'),
-            context=request),
-        'placeholder': translate(_('Enter time...'), context=request),
-    }
     return options
 
 
@@ -225,7 +207,7 @@ def get_tinymce_options(context, field, request):
             name="plone_settings").tinymce()['data-pat-tinymce']
         options = json.loads(pattern_options)
     except (ComponentLookupError, AttributeError):
-        pass
+        logger.warning("Can not load tinymce pattern options!", exc_info=True)
     return options
 
 
